Class: FreightFinancialsWebhookIngestionApi::ChargeCode
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- FreightFinancialsWebhookIngestionApi::ChargeCode
- Defined in:
- lib/freight_financials_webhook_ingestion_api/models/charge_code.rb
Overview
ChargeCode Model.
Instance Attribute Summary collapse
-
#description ⇒ String
TODO: Write general description for this method.
-
#origin ⇒ Integer
TODO: Write general description for this method.
-
#value ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(description: SKIP, origin: SKIP, value: SKIP) ⇒ ChargeCode
constructor
A new instance of ChargeCode.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(description: SKIP, origin: SKIP, value: SKIP) ⇒ ChargeCode
Returns a new instance of ChargeCode.
47 48 49 50 51 |
# File 'lib/freight_financials_webhook_ingestion_api/models/charge_code.rb', line 47 def initialize(description: SKIP, origin: SKIP, value: SKIP) @description = description unless description == SKIP @origin = origin unless origin == SKIP @value = value unless value == SKIP end |
Instance Attribute Details
#description ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/freight_financials_webhook_ingestion_api/models/charge_code.rb', line 14 def description @description end |
#origin ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/freight_financials_webhook_ingestion_api/models/charge_code.rb', line 18 def origin @origin end |
#value ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/freight_financials_webhook_ingestion_api/models/charge_code.rb', line 22 def value @value end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/freight_financials_webhook_ingestion_api/models/charge_code.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. description = hash.key?('description') ? hash['description'] : SKIP origin = hash.key?('origin') ? hash['origin'] : SKIP value = hash.key?('value') ? hash['value'] : SKIP # Create object from extracted values. ChargeCode.new(description: description, origin: origin, value: value) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/freight_financials_webhook_ingestion_api/models/charge_code.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['description'] = 'description' @_hash['origin'] = 'origin' @_hash['value'] = 'value' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/freight_financials_webhook_ingestion_api/models/charge_code.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/freight_financials_webhook_ingestion_api/models/charge_code.rb', line 34 def self.optionals %w[ description origin value ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
75 76 77 78 79 |
# File 'lib/freight_financials_webhook_ingestion_api/models/charge_code.rb', line 75 def inspect class_name = self.class.name.split('::').last "<#{class_name} description: #{@description.inspect}, origin: #{@origin.inspect}, value:"\ " #{@value.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
69 70 71 72 |
# File 'lib/freight_financials_webhook_ingestion_api/models/charge_code.rb', line 69 def to_s class_name = self.class.name.split('::').last "<#{class_name} description: #{@description}, origin: #{@origin}, value: #{@value}>" end |