Class: FreightFinancialsWebhookIngestionApi::FactoringCompany
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- FreightFinancialsWebhookIngestionApi::FactoringCompany
- Defined in:
- lib/freight_financials_webhook_ingestion_api/models/factoring_company.rb
Overview
FactoringCompany Model.
Instance Attribute Summary collapse
-
#company_name ⇒ String
TODO: Write general description for this method.
-
#email ⇒ String
TODO: Write general description for this method.
-
#phone ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(company_name: SKIP, email: SKIP, phone: SKIP) ⇒ FactoringCompany
constructor
A new instance of FactoringCompany.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(company_name: SKIP, email: SKIP, phone: SKIP) ⇒ FactoringCompany
Returns a new instance of FactoringCompany.
47 48 49 50 51 |
# File 'lib/freight_financials_webhook_ingestion_api/models/factoring_company.rb', line 47 def initialize(company_name: SKIP, email: SKIP, phone: SKIP) @company_name = company_name unless company_name == SKIP @email = email unless email == SKIP @phone = phone unless phone == SKIP end |
Instance Attribute Details
#company_name ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/freight_financials_webhook_ingestion_api/models/factoring_company.rb', line 14 def company_name @company_name end |
#email ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/freight_financials_webhook_ingestion_api/models/factoring_company.rb', line 18 def email @email end |
#phone ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/freight_financials_webhook_ingestion_api/models/factoring_company.rb', line 22 def phone @phone end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/freight_financials_webhook_ingestion_api/models/factoring_company.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. company_name = hash.key?('companyName') ? hash['companyName'] : SKIP email = hash.key?('email') ? hash['email'] : SKIP phone = hash.key?('phone') ? hash['phone'] : SKIP # Create object from extracted values. FactoringCompany.new(company_name: company_name, email: email, phone: phone) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/freight_financials_webhook_ingestion_api/models/factoring_company.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['company_name'] = 'companyName' @_hash['email'] = 'email' @_hash['phone'] = 'phone' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/freight_financials_webhook_ingestion_api/models/factoring_company.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/freight_financials_webhook_ingestion_api/models/factoring_company.rb', line 34 def self.optionals %w[ company_name email phone ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
75 76 77 78 79 |
# File 'lib/freight_financials_webhook_ingestion_api/models/factoring_company.rb', line 75 def inspect class_name = self.class.name.split('::').last "<#{class_name} company_name: #{@company_name.inspect}, email: #{@email.inspect}, phone:"\ " #{@phone.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
69 70 71 72 |
# File 'lib/freight_financials_webhook_ingestion_api/models/factoring_company.rb', line 69 def to_s class_name = self.class.name.split('::').last "<#{class_name} company_name: #{@company_name}, email: #{@email}, phone: #{@phone}>" end |