Class: FreightFinancialsWebhookIngestionApi::InvoiceDocument
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- FreightFinancialsWebhookIngestionApi::InvoiceDocument
- Defined in:
- lib/freight_financials_webhook_ingestion_api/models/invoice_document.rb
Overview
InvoiceDocument Model.
Instance Attribute Summary collapse
-
#document_id ⇒ UUID | String
TODO: Write general description for this method.
-
#document_type ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(document_id: SKIP, document_type: SKIP) ⇒ InvoiceDocument
constructor
A new instance of InvoiceDocument.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(document_id: SKIP, document_type: SKIP) ⇒ InvoiceDocument
Returns a new instance of InvoiceDocument.
41 42 43 44 |
# File 'lib/freight_financials_webhook_ingestion_api/models/invoice_document.rb', line 41 def initialize(document_id: SKIP, document_type: SKIP) @document_id = document_id unless document_id == SKIP @document_type = document_type unless document_type == SKIP end |
Instance Attribute Details
#document_id ⇒ UUID | String
TODO: Write general description for this method
14 15 16 |
# File 'lib/freight_financials_webhook_ingestion_api/models/invoice_document.rb', line 14 def document_id @document_id end |
#document_type ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/freight_financials_webhook_ingestion_api/models/invoice_document.rb', line 18 def document_type @document_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/freight_financials_webhook_ingestion_api/models/invoice_document.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. document_id = hash.key?('documentId') ? hash['documentId'] : SKIP document_type = hash.key?('documentType') ? hash['documentType'] : SKIP # Create object from extracted values. InvoiceDocument.new(document_id: document_id, document_type: document_type) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/freight_financials_webhook_ingestion_api/models/invoice_document.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['document_id'] = 'documentId' @_hash['document_type'] = 'documentType' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/freight_financials_webhook_ingestion_api/models/invoice_document.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/freight_financials_webhook_ingestion_api/models/invoice_document.rb', line 29 def self.optionals %w[ document_id document_type ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
66 67 68 69 70 |
# File 'lib/freight_financials_webhook_ingestion_api/models/invoice_document.rb', line 66 def inspect class_name = self.class.name.split('::').last "<#{class_name} document_id: #{@document_id.inspect}, document_type:"\ " #{@document_type.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
60 61 62 63 |
# File 'lib/freight_financials_webhook_ingestion_api/models/invoice_document.rb', line 60 def to_s class_name = self.class.name.split('::').last "<#{class_name} document_id: #{@document_id}, document_type: #{@document_type}>" end |