Class: FreightFinancialsWebhookIngestionApi::LoadsApi

Inherits:
BaseApi
  • Object
show all
Defined in:
lib/freight_financials_webhook_ingestion_api/apis/loads_api.rb

Overview

LoadsApi

Constant Summary

Constants inherited from BaseApi

BaseApi::GLOBAL_ERRORS

Instance Attribute Summary

Attributes inherited from BaseApi

#config, #http_call_back

Instance Method Summary collapse

Methods inherited from BaseApi

#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters

Constructor Details

This class inherits a constructor from FreightFinancialsWebhookIngestionApi::BaseApi

Instance Method Details

#get_load(load_number, x_tenant_id, api_version: nil) ⇒ ApiResponse

TODO: type endpoint description here by APIM. Required on all requests. here

Parameters:

  • load_number (String)

    Required parameter: The TQL load number.

  • x_tenant_id (String)

    Required parameter: Tenant identifier stamped

  • api_version (String) (defaults to: nil)

    Optional parameter: TODO: type description

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/freight_financials_webhook_ingestion_api/apis/loads_api.rb', line 48

def get_load(load_number,
             x_tenant_id,
             api_version: nil)
  @api_call
    .request(new_request_builder(HttpMethodEnum::GET,
                                 '/api/v1/Loads/{loadNumber}',
                                 Server::DEFAULT)
               .template_param(new_parameter(load_number, key: 'loadNumber')
                                .is_required(true)
                                .should_encode(true))
               .header_param(new_parameter(x_tenant_id, key: 'X-Tenant-Id')
                              .is_required(true))
               .query_param(new_parameter(api_version, key: 'api-version'))
               .header_param(new_parameter('application/json', key: 'accept')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(LoadResponse.method(:from_hash))
                .is_api_response(true)
                .local_error('404',
                             'No load exists with the specified load number.',
                             ProblemDetailsException))
    .execute
end

#search_loads(x_tenant_id, body, api_version: nil) ⇒ ApiResponse

TODO: type endpoint description here by APIM. Required on all requests. here

Parameters:

  • x_tenant_id (String)

    Required parameter: Tenant identifier stamped

  • body (SearchRequest)

    Required parameter: Cancellation token.

  • api_version (String) (defaults to: nil)

    Optional parameter: TODO: type description

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
# File 'lib/freight_financials_webhook_ingestion_api/apis/loads_api.rb', line 16

def search_loads(x_tenant_id,
                 body,
                 api_version: nil)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/api/v1/Loads/search',
                                 Server::DEFAULT)
               .header_param(new_parameter(x_tenant_id, key: 'X-Tenant-Id')
                              .is_required(true))
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .body_param(new_parameter(body)
                            .is_required(true))
               .query_param(new_parameter(api_version, key: 'api-version'))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(SearchResponse.method(:from_hash))
                .is_api_response(true)
                .local_error('400',
                             'Invalid filter criteria or pagination parameters.',
                             ProblemDetailsException))
    .execute
end