Class: FreightFinancialsWebhookIngestionApi::Stop
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- FreightFinancialsWebhookIngestionApi::Stop
- Defined in:
- lib/freight_financials_webhook_ingestion_api/models/stop.rb
Overview
Stop Model.
Instance Attribute Summary collapse
-
#location ⇒ Address
TODO: Write general description for this method.
-
#sequence ⇒ Integer
TODO: Write general description for this method.
-
#stop_type ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(location: SKIP, sequence: SKIP, stop_type: SKIP) ⇒ Stop
constructor
A new instance of Stop.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(location: SKIP, sequence: SKIP, stop_type: SKIP) ⇒ Stop
Returns a new instance of Stop.
47 48 49 50 51 |
# File 'lib/freight_financials_webhook_ingestion_api/models/stop.rb', line 47 def initialize(location: SKIP, sequence: SKIP, stop_type: SKIP) @location = location unless location == SKIP @sequence = sequence unless sequence == SKIP @stop_type = stop_type unless stop_type == SKIP end |
Instance Attribute Details
#location ⇒ Address
TODO: Write general description for this method
14 15 16 |
# File 'lib/freight_financials_webhook_ingestion_api/models/stop.rb', line 14 def location @location end |
#sequence ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/freight_financials_webhook_ingestion_api/models/stop.rb', line 18 def sequence @sequence end |
#stop_type ⇒ Integer
TODO: Write general description for this method
22 23 24 |
# File 'lib/freight_financials_webhook_ingestion_api/models/stop.rb', line 22 def stop_type @stop_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/freight_financials_webhook_ingestion_api/models/stop.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. location = Address.from_hash(hash['location']) if hash['location'] sequence = hash.key?('sequence') ? hash['sequence'] : SKIP stop_type = hash.key?('stopType') ? hash['stopType'] : SKIP # Create object from extracted values. Stop.new(location: location, sequence: sequence, stop_type: stop_type) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/freight_financials_webhook_ingestion_api/models/stop.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['location'] = 'location' @_hash['sequence'] = 'sequence' @_hash['stop_type'] = 'stopType' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/freight_financials_webhook_ingestion_api/models/stop.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/freight_financials_webhook_ingestion_api/models/stop.rb', line 34 def self.optionals %w[ location sequence stop_type ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
75 76 77 78 79 |
# File 'lib/freight_financials_webhook_ingestion_api/models/stop.rb', line 75 def inspect class_name = self.class.name.split('::').last "<#{class_name} location: #{@location.inspect}, sequence: #{@sequence.inspect}, stop_type:"\ " #{@stop_type.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
69 70 71 72 |
# File 'lib/freight_financials_webhook_ingestion_api/models/stop.rb', line 69 def to_s class_name = self.class.name.split('::').last "<#{class_name} location: #{@location}, sequence: #{@sequence}, stop_type: #{@stop_type}>" end |