Class: FreightFinancialsWebhookIngestionApi::SubmitInvoiceResponseData

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/freight_financials_webhook_ingestion_api/models/submit_invoice_response_data.rb

Overview

SubmitInvoiceResponseData Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(invoice_number: SKIP, received_at: SKIP, status: SKIP, additional_properties: nil) ⇒ SubmitInvoiceResponseData

Returns a new instance of SubmitInvoiceResponseData.



48
49
50
51
52
53
54
55
56
57
# File 'lib/freight_financials_webhook_ingestion_api/models/submit_invoice_response_data.rb', line 48

def initialize(invoice_number: SKIP, received_at: SKIP, status: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @invoice_number = invoice_number unless invoice_number == SKIP
  @received_at = received_at unless received_at == SKIP
  @status = status unless status == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#invoice_numberString

TODO: Write general description for this method

Returns:

  • (String)


15
16
17
# File 'lib/freight_financials_webhook_ingestion_api/models/submit_invoice_response_data.rb', line 15

def invoice_number
  @invoice_number
end

#received_atDateTime

TODO: Write general description for this method

Returns:

  • (DateTime)


19
20
21
# File 'lib/freight_financials_webhook_ingestion_api/models/submit_invoice_response_data.rb', line 19

def received_at
  @received_at
end

#statusInteger

TODO: Write general description for this method

Returns:

  • (Integer)


23
24
25
# File 'lib/freight_financials_webhook_ingestion_api/models/submit_invoice_response_data.rb', line 23

def status
  @status
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/freight_financials_webhook_ingestion_api/models/submit_invoice_response_data.rb', line 60

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  invoice_number = hash.key?('invoiceNumber') ? hash['invoiceNumber'] : SKIP
  received_at = if hash.key?('receivedAt')
                  (DateTimeHelper.from_rfc3339(hash['receivedAt']) if hash['receivedAt'])
                else
                  SKIP
                end
  status = hash.key?('status') ? hash['status'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  SubmitInvoiceResponseData.new(invoice_number: invoice_number,
                                received_at: received_at,
                                status: status,
                                additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



26
27
28
29
30
31
32
# File 'lib/freight_financials_webhook_ingestion_api/models/submit_invoice_response_data.rb', line 26

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['invoice_number'] = 'invoiceNumber'
  @_hash['received_at'] = 'receivedAt'
  @_hash['status'] = 'status'
  @_hash
end

.nullablesObject

An array for nullable fields



44
45
46
# File 'lib/freight_financials_webhook_ingestion_api/models/submit_invoice_response_data.rb', line 44

def self.nullables
  []
end

.optionalsObject

An array for optional fields



35
36
37
38
39
40
41
# File 'lib/freight_financials_webhook_ingestion_api/models/submit_invoice_response_data.rb', line 35

def self.optionals
  %w[
    invoice_number
    received_at
    status
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



98
99
100
101
102
103
# File 'lib/freight_financials_webhook_ingestion_api/models/submit_invoice_response_data.rb', line 98

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} invoice_number: #{@invoice_number.inspect}, received_at:"\
  " #{@received_at.inspect}, status: #{@status.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_custom_received_atObject



86
87
88
# File 'lib/freight_financials_webhook_ingestion_api/models/submit_invoice_response_data.rb', line 86

def to_custom_received_at
  DateTimeHelper.to_rfc3339(received_at)
end

#to_sObject

Provides a human-readable string representation of the object.



91
92
93
94
95
# File 'lib/freight_financials_webhook_ingestion_api/models/submit_invoice_response_data.rb', line 91

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} invoice_number: #{@invoice_number}, received_at: #{@received_at}, status:"\
  " #{@status}, additional_properties: #{@additional_properties}>"
end