Class: TqlOtrFactoringDataExchange::Document
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- TqlOtrFactoringDataExchange::Document
- Defined in:
- lib/tql_otr_factoring_data_exchange/models/document.rb
Overview
Document Model.
Instance Attribute Summary collapse
-
#document_id ⇒ UUID | String
System-generated document identifier.
-
#document_type ⇒ DocumentType
Document type classification used for categorizing uploaded documents.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(document_id: SKIP, document_type: SKIP, additional_properties: nil) ⇒ Document
constructor
A new instance of Document.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(document_id: SKIP, document_type: SKIP, additional_properties: nil) ⇒ Document
Returns a new instance of Document.
41 42 43 44 45 46 47 48 49 |
# File 'lib/tql_otr_factoring_data_exchange/models/document.rb', line 41 def initialize(document_id: SKIP, document_type: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @document_id = document_id unless document_id == SKIP @document_type = document_type unless document_type == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#document_id ⇒ UUID | String
System-generated document identifier.
14 15 16 |
# File 'lib/tql_otr_factoring_data_exchange/models/document.rb', line 14 def document_id @document_id end |
#document_type ⇒ DocumentType
Document type classification used for categorizing uploaded documents.
18 19 20 |
# File 'lib/tql_otr_factoring_data_exchange/models/document.rb', line 18 def document_type @document_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/tql_otr_factoring_data_exchange/models/document.rb', line 52 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. document_id = hash.key?('documentId') ? hash['documentId'] : SKIP document_type = hash.key?('documentType') ? hash['documentType'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Document.new(document_id: document_id, document_type: document_type, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/tql_otr_factoring_data_exchange/models/document.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['document_id'] = 'documentId' @_hash['document_type'] = 'documentType' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/tql_otr_factoring_data_exchange/models/document.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/tql_otr_factoring_data_exchange/models/document.rb', line 29 def self.optionals %w[ document_id document_type ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
80 81 82 83 84 |
# File 'lib/tql_otr_factoring_data_exchange/models/document.rb', line 80 def inspect class_name = self.class.name.split('::').last "<#{class_name} document_id: #{@document_id.inspect}, document_type:"\ " #{@document_type.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
73 74 75 76 77 |
# File 'lib/tql_otr_factoring_data_exchange/models/document.rb', line 73 def to_s class_name = self.class.name.split('::').last "<#{class_name} document_id: #{@document_id}, document_type: #{@document_type},"\ " additional_properties: #{@additional_properties}>" end |