Class: TqlOtrFactoringDataExchange::SubmitInvoiceResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/tql_otr_factoring_data_exchange/models/submit_invoice_response.rb

Overview

Acknowledgement that the invoice was accepted for processing.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(invoice_number: SKIP, status: SKIP, received_at: SKIP, additional_properties: nil) ⇒ SubmitInvoiceResponse

Returns a new instance of SubmitInvoiceResponse.



51
52
53
54
55
56
57
58
59
60
# File 'lib/tql_otr_factoring_data_exchange/models/submit_invoice_response.rb', line 51

def initialize(invoice_number: SKIP, status: SKIP, received_at: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @invoice_number = invoice_number unless invoice_number == SKIP
  @status = status unless status == SKIP
  @received_at = received_at unless received_at == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#invoice_numberString

The factoring company’s invoice number (echoed back).

Returns:

  • (String)


15
16
17
# File 'lib/tql_otr_factoring_data_exchange/models/submit_invoice_response.rb', line 15

def invoice_number
  @invoice_number
end

#received_atDateTime

UTC timestamp indicating when the invoice was received.

Returns:

  • (DateTime)


26
27
28
# File 'lib/tql_otr_factoring_data_exchange/models/submit_invoice_response.rb', line 26

def received_at
  @received_at
end

#statusInvoiceStatus

Processing and payment status of an invoice. The lifecycle typically flows: ‘Received` → `Validating` → `Processing` → `Approved` → `NotPaid` →`Paid`. Branches include `AwaitingDocuments`, `PendingExceptions`, and `Rejected`.

Returns:



22
23
24
# File 'lib/tql_otr_factoring_data_exchange/models/submit_invoice_response.rb', line 22

def status
  @status
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/tql_otr_factoring_data_exchange/models/submit_invoice_response.rb', line 63

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  invoice_number = hash.key?('invoiceNumber') ? hash['invoiceNumber'] : SKIP
  status = hash.key?('status') ? hash['status'] : SKIP
  received_at = if hash.key?('receivedAt')
                  (DateTimeHelper.from_rfc3339(hash['receivedAt']) if hash['receivedAt'])
                else
                  SKIP
                end

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  SubmitInvoiceResponse.new(invoice_number: invoice_number,
                            status: status,
                            received_at: received_at,
                            additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
35
# File 'lib/tql_otr_factoring_data_exchange/models/submit_invoice_response.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['invoice_number'] = 'invoiceNumber'
  @_hash['status'] = 'status'
  @_hash['received_at'] = 'receivedAt'
  @_hash
end

.nullablesObject

An array for nullable fields



47
48
49
# File 'lib/tql_otr_factoring_data_exchange/models/submit_invoice_response.rb', line 47

def self.nullables
  []
end

.optionalsObject

An array for optional fields



38
39
40
41
42
43
44
# File 'lib/tql_otr_factoring_data_exchange/models/submit_invoice_response.rb', line 38

def self.optionals
  %w[
    invoice_number
    status
    received_at
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



101
102
103
104
105
# File 'lib/tql_otr_factoring_data_exchange/models/submit_invoice_response.rb', line 101

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} invoice_number: #{@invoice_number.inspect}, status: #{@status.inspect},"\
  " received_at: #{@received_at.inspect}, additional_properties: #{@additional_properties}>"
end

#to_custom_received_atObject



89
90
91
# File 'lib/tql_otr_factoring_data_exchange/models/submit_invoice_response.rb', line 89

def to_custom_received_at
  DateTimeHelper.to_rfc3339(received_at)
end

#to_sObject

Provides a human-readable string representation of the object.



94
95
96
97
98
# File 'lib/tql_otr_factoring_data_exchange/models/submit_invoice_response.rb', line 94

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} invoice_number: #{@invoice_number}, status: #{@status}, received_at:"\
  " #{@received_at}, additional_properties: #{@additional_properties}>"
end