Class: FreightFinancialsWebhookIngestionApi::NavixRateVendor
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- FreightFinancialsWebhookIngestionApi::NavixRateVendor
- Defined in:
- lib/freight_financials_webhook_ingestion_api/models/navix_rate_vendor.rb
Overview
NavixRateVendor Model.
Instance Attribute Summary collapse
-
#external_id ⇒ String
TODO: Write general description for this method.
-
#scac ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(external_id: SKIP, scac: SKIP, additional_properties: nil) ⇒ NavixRateVendor
constructor
A new instance of NavixRateVendor.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(external_id: SKIP, scac: SKIP, additional_properties: nil) ⇒ NavixRateVendor
Returns a new instance of NavixRateVendor.
44 45 46 47 48 49 50 51 |
# File 'lib/freight_financials_webhook_ingestion_api/models/navix_rate_vendor.rb', line 44 def initialize(external_id: SKIP, scac: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @external_id = external_id unless external_id == SKIP @scac = scac unless scac == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#external_id ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/freight_financials_webhook_ingestion_api/models/navix_rate_vendor.rb', line 14 def external_id @external_id end |
#scac ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/freight_financials_webhook_ingestion_api/models/navix_rate_vendor.rb', line 18 def scac @scac end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/freight_financials_webhook_ingestion_api/models/navix_rate_vendor.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. external_id = hash.key?('externalId') ? hash['externalId'] : SKIP scac = hash.key?('SCAC') ? hash['SCAC'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. NavixRateVendor.new(external_id: external_id, scac: scac, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/freight_financials_webhook_ingestion_api/models/navix_rate_vendor.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['external_id'] = 'externalId' @_hash['scac'] = 'SCAC' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 40 41 42 |
# File 'lib/freight_financials_webhook_ingestion_api/models/navix_rate_vendor.rb', line 37 def self.nullables %w[ external_id scac ] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/freight_financials_webhook_ingestion_api/models/navix_rate_vendor.rb', line 29 def self.optionals %w[ external_id scac ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
82 83 84 85 86 |
# File 'lib/freight_financials_webhook_ingestion_api/models/navix_rate_vendor.rb', line 82 def inspect class_name = self.class.name.split('::').last "<#{class_name} external_id: #{@external_id.inspect}, scac: #{@scac.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
75 76 77 78 79 |
# File 'lib/freight_financials_webhook_ingestion_api/models/navix_rate_vendor.rb', line 75 def to_s class_name = self.class.name.split('::').last "<#{class_name} external_id: #{@external_id}, scac: #{@scac}, additional_properties:"\ " #{@additional_properties}>" end |