Class: TqlOtrFactoringDataExchange::ProblemDetails
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- TqlOtrFactoringDataExchange::ProblemDetails
- Defined in:
- lib/tql_otr_factoring_data_exchange/models/problem_details.rb
Overview
[RFC 7807](datatracker.ietf.org/doc/html/rfc7807) Problem Details response returned for validation errors and other non-success outcomes.
Instance Attribute Summary collapse
-
#detail ⇒ String
Detailed, human-readable explanation specific to this occurrence.
-
#status ⇒ Integer
HTTP status code.
-
#title ⇒ String
Short, human-readable summary of the problem type.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(title: SKIP, status: SKIP, detail: SKIP, additional_properties: nil) ⇒ ProblemDetails
constructor
A new instance of ProblemDetails.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(title: SKIP, status: SKIP, detail: SKIP, additional_properties: nil) ⇒ ProblemDetails
Returns a new instance of ProblemDetails.
48 49 50 51 52 53 54 55 56 57 |
# File 'lib/tql_otr_factoring_data_exchange/models/problem_details.rb', line 48 def initialize(title: SKIP, status: SKIP, detail: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @title = title unless title == SKIP @status = status unless status == SKIP @detail = detail unless detail == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#detail ⇒ String
Detailed, human-readable explanation specific to this occurrence.
23 24 25 |
# File 'lib/tql_otr_factoring_data_exchange/models/problem_details.rb', line 23 def detail @detail end |
#status ⇒ Integer
HTTP status code.
19 20 21 |
# File 'lib/tql_otr_factoring_data_exchange/models/problem_details.rb', line 19 def status @status end |
#title ⇒ String
Short, human-readable summary of the problem type.
15 16 17 |
# File 'lib/tql_otr_factoring_data_exchange/models/problem_details.rb', line 15 def title @title end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/tql_otr_factoring_data_exchange/models/problem_details.rb', line 60 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. title = hash.key?('title') ? hash['title'] : SKIP status = hash.key?('status') ? hash['status'] : SKIP detail = hash.key?('detail') ? hash['detail'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ProblemDetails.new(title: title, status: status, detail: detail, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
26 27 28 29 30 31 32 |
# File 'lib/tql_otr_factoring_data_exchange/models/problem_details.rb', line 26 def self.names @_hash = {} if @_hash.nil? @_hash['title'] = 'title' @_hash['status'] = 'status' @_hash['detail'] = 'detail' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/tql_otr_factoring_data_exchange/models/problem_details.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
35 36 37 38 39 40 41 |
# File 'lib/tql_otr_factoring_data_exchange/models/problem_details.rb', line 35 def self.optionals %w[ title status detail ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
90 91 92 93 94 |
# File 'lib/tql_otr_factoring_data_exchange/models/problem_details.rb', line 90 def inspect class_name = self.class.name.split('::').last "<#{class_name} title: #{@title.inspect}, status: #{@status.inspect}, detail:"\ " #{@detail.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
83 84 85 86 87 |
# File 'lib/tql_otr_factoring_data_exchange/models/problem_details.rb', line 83 def to_s class_name = self.class.name.split('::').last "<#{class_name} title: #{@title}, status: #{@status}, detail: #{@detail},"\ " additional_properties: #{@additional_properties}>" end |